@@ -49,7 +49,7 @@ namespace Imendio.Blam {
 
         //[Widget] Gtk.MenuItem       printMenuItem;
 
-        private Gtk.FileSelection   exportFileDialog;
+        private Gtk.FileChooserDialog   exportFileDialog;
 
         private ChannelList channelList;
         private ItemList    itemList;
@@ -181,7 +181,6 @@ namespace Imendio.Blam {
             itemList.ItemSelected += ItemSelected;
 
             trayIcon = new TrayIcon (Catalog.GetString ("Imendio Blam News Reader"));
-            trayIcon.Image.Pixbuf = Gdk.Pixbuf.LoadFromResource ("blam-tray-icon.png");
             trayIcon.ButtonPressEvent += TrayIconButtonPressCb;
             channelsLabelText = channelsLabel.Text;
             UpdateTotalNumberOfUnread ();
@@ -196,7 +195,7 @@ namespace Imendio.Blam {
 
             RestoreWindowState();
 
-            mainWindow.Icon = Gdk.Pixbuf.LoadFromResource("blam.png");
+            mainWindow.IconName = "blam";
 
             mainWindow.ShowAll ();
 
@@ -210,17 +209,13 @@ namespace Imendio.Blam {
         }
 
 #if ENABLE_DBUS
-        private DBus.Connection dbusConnection;
-        private void SetupDBus ()
+        private void SetupDBus()
         {
-            try {
-                this.dbusConnection = DBus.Bus.GetSessionBus ();
-                DBus.Service service = new DBus.Service (this.dbusConnection, DBusFeedReaderProxy.Service);
-
-                DBusFeedReader feedReader = new DBusFeedReader (this);
-                service.RegisterObject(feedReader, DBusFeedReaderProxy.ObjectPath);
-            } catch (Exception e) {
-                Console.WriteLine("Failed to init dbus interface, I won't receive any dbus message, be warned !");
+            try{
+                DBusMgr dbusmgr = new DBusMgr(this);
+                dbusmgr.Register();
+            } catch (Exception e){
+                Console.WriteLine("Unable to start DBus interface: {0}", e.Message);
             }
         }
 #else
@@ -330,7 +325,7 @@ namespace Imendio.Blam {
                 nextUnreadMenuItem.Activate ();
                 break;
             case (Gdk.Key.Escape):
-                mainWindow.Iconify ();
+                mainWindow.Hide ();
                 break;
             }
         }
@@ -370,9 +365,12 @@ namespace Imendio.Blam {
         public void ExportOpmlActivated (object obj, EventArgs args)
         {
             if (exportFileDialog == null) {
-                exportFileDialog = new Gtk.FileSelection (Catalog.GetString ("Export to..."));
+                exportFileDialog = new Gtk.FileChooserDialog (Catalog.GetString ("Export to..."),
+                                      mainWindow, FileChooserAction.Save,
+                                      Catalog.GetString("Cancel"), ResponseType.Cancel,
+                                      Catalog.GetString("Save"), ResponseType.Ok);
+                exportFileDialog.IconName = "blam";
                 exportFileDialog.Modal = true;
-                exportFileDialog.ShowFileops = true;
                 exportFileDialog.TransientFor = mainWindow;
             }
 
@@ -421,7 +419,9 @@ namespace Imendio.Blam {
 
         public void DeleteEventTriggered(object obj, DeleteEventArgs args)
         {
-            QuitActivated(obj, null);
+            mainWindow.Hide(); // only exit if we choose File|Quit
+            trayIcon.Show();
+            args.RetVal = true;
         }
 
         public void QuitActivated(object obj, EventArgs args)
@@ -430,6 +430,7 @@ namespace Imendio.Blam {
             mainWindow.Hide();
 
             mCollection.SaveToFile ();
+            mCollection.StopAllThreads();
 
             Quit();
         }
@@ -447,7 +448,7 @@ namespace Imendio.Blam {
 
         public void AboutActivated (object obj, EventArgs args)
         {
-            About.Show (mainWindow);
+            new AboutDialog(mainWindow);
         }
 
         public void AddChannelActivated (object obj, EventArgs args)
@@ -630,7 +631,7 @@ namespace Imendio.Blam {
             }
         }
 
-        private void TrayIconButtonPressCb (object o, ButtonPressEventArgs args)
+        private void TrayIconButtonPressCb (object o, EventArgs args)
         {
             mainWindow.Present ();
         }
@@ -702,12 +703,13 @@ namespace Imendio.Blam {
                                                  channelsLabelText +
                                                  "</b>",
                                                  nrOfUnread);
-            if (nrOfUnread > 0) {
-                trayIcon.Show ();
-                trayIcon.Tooltip = string.Format (Catalog.GetPluralString ("{0} unread item", "{0} unread items", nrOfUnread),
-                                                  nrOfUnread);
+
+            trayIcon.Tooltip = string.Format (Catalog.GetPluralString ("{0} unread item", "{0} unread items", nrOfUnread),
+                                             nrOfUnread);
+            if(nrOfUnread > 0 || !mainWindow.Visible){
+                trayIcon.Show();
             } else {
-                trayIcon.Hide ();
+                trayIcon.Hide();
             }
         }
 
