@@ -5,8 +5,7 @@
 // 
 
 using Rss;
-using Atom.Core;
-using Atom.Core.Collections;
+using Atom;
 using System.Collections;
 using System;
 using System.Net;
