@@ -161,6 +161,8 @@ namespace Imendio.Blam {
 	    if (ChannelAdded != null) {
 		ChannelAdded (channel);
 	    }
+
+        MarkAsDirty(true);
 	}
 
 	public void Update (Channel channel)
@@ -179,6 +181,8 @@ namespace Imendio.Blam {
 	    if (ChannelRemoved != null) {
 		ChannelRemoved (channel);
 	    }
+
+        MarkAsDirty(true);
 	}
 
 	public void Refresh (Channel channel) 
@@ -208,6 +212,16 @@ namespace Imendio.Blam {
 	    }
 	}
 
+    public void StopAllThreads()
+    {
+        foreach(Thread t in mRunningList){
+            t.Abort();
+        }
+
+        mRunningList.Clear();
+        mQueue.Clear();
+    }
+
 	public void RefreshAll ()
 	{
 	    int nrOfChannels = 0;
