@@ -6,8 +6,7 @@
 // 
 
 using Rss;
-using Atom.Core;
-using Atom.Core.Collections;
+using Atom;
 using System;
 using System.IO;
 using System.Net;
@@ -39,11 +38,11 @@ namespace Imendio.Blam {
     }
     public class FeedUpdater {
     
-    private static string feed_type(Stream feed)
+    private static string feed_type(ref string feed)
     {
         string type = null;
 
-        XPathDocument doc = new XPathDocument(feed);
+        XPathDocument doc = new XPathDocument(new StringReader(feed));
         XPathNavigator nav = doc.CreateNavigator();
         XmlNamespaceManager nsm = new XmlNamespaceManager(nav.NameTable);
         XPathExpression expr = nav.Compile("/atom03:feed|/atom10:feed");
@@ -79,18 +78,35 @@ namespace Imendio.Blam {
         channel.LastRefreshed = DateTime.Now;
 
         bool updated = false;
-        WebResponse res = GetChannelData(channel);
-        Stream stream = null;
+        WebResponse res = null;
+        bool remote = true; /* Wether the feed is local or remote. */
+        StreamReader stream = null;
+        string feed = null;
 
-        if(res == null){
-            return false; /* Feed hasn't changed or we couldn't connect. */
+        if(channel.Url.StartsWith("/") || channel.Url.StartsWith("file:")){
+            remote = false;
+        }
+
+        if(remote){
+            res = GetRemoteChannelData(channel);
+
+            if(res == null){
+                return false; /* Feed hasn't changed or we couldn't connect. */
+            }
+
+            stream = new StreamReader(res.GetResponseStream());
+            feed = stream.ReadToEnd();
+            stream.Close();
+        } else {
+            feed = GetLocalChannel(channel);
+            if(feed == string.Empty){
+                return false;
+            }
         }
 
-        stream = res.GetResponseStream();
-	    
         if(channel.Type == ""){
 
-            string type = feed_type(stream);
+            string type = feed_type(ref feed);
             
             /* If we know for certain, assign it directly. */
             if(type == "Atom 0.3" || type == "Atom 1.0"){
@@ -98,7 +114,7 @@ namespace Imendio.Blam {
             } else {
                 try{
                 /* We don't know the type of feed. Try RSS. */
-                RssReader reader = new RssReader(GetChannelData(channel).GetResponseStream());
+                RssReader reader = new RssReader(new StringReader(feed));
                 RssElement e = reader.Read();
                     
                 if(e != null){ /* If the RSS library will take it, we say it's RSS. */
@@ -111,13 +127,12 @@ namespace Imendio.Blam {
                 }
                 
                 reader.Close();
-                res.Close();
                     
                 } catch(Exception e){
                     System.Console.WriteLine("Error whilst determining feed type: {0}", e.Message);
                 }
             }
-            
+
             /* If it's still unknown, we don't speak it. */
             if(channel.Type == ""){
                 return false;
@@ -126,21 +141,23 @@ namespace Imendio.Blam {
 
         try {
             
-            stream = GetChannelData(channel).GetResponseStream();
             if (channel.Type == "RSS") {
-                updated = UpdateRssChannel(channel, stream);
+                updated = UpdateRssChannel(channel, ref feed);
             } else if (channel.Type == "Atom") {
-                updated = UpdateAtomChannel(channel, stream);
+                updated = UpdateAtomChannel(channel, ref feed);
             }
 
-            if (res.Headers.Get("Last-Modified") != null) {
-                channel.LastModified = res.Headers.Get("Last-Modified"); 
-            }
-            if (res.Headers.Get("ETag") != null) {
-                channel.ETag = res.Headers.Get("ETag");
+            if(remote){
+                if (res.Headers.Get("Last-Modified") != null) {
+                    channel.LastModified = res.Headers.Get("Last-Modified");
+                }
+                if (res.Headers.Get("ETag") != null) {
+                    channel.ETag = res.Headers.Get("ETag");
+                }
+
+                res.Close();
             }
 
-            res.Close ();
         } catch (Exception e) {
             Console.WriteLine("Error whilst updating the feed {0}: {1}", channel.Name, e.Message);
         }
@@ -172,7 +189,7 @@ namespace Imendio.Blam {
         }
     }
 
-	public static WebResponse GetChannelData (Channel channel)
+	private static WebResponse GetRemoteChannelData (Channel channel)
 	{
 	    HttpWebRequest req = null;
 	    WebResponse res = null;
@@ -237,11 +254,45 @@ namespace Imendio.Blam {
 	    return res;
 	}
 
-	private static bool UpdateRssChannel (Channel channel, Stream stream)
+    private static string GetLocalChannel(Channel channel)
+    {
+        string fs_path = null;
+        TextReader reader = null;
+        int offset = -1;
+
+        /*
+         * First, we determine the format the feed was given in. We accept
+         * several variants: "file:/u/feed.xml", "file:///u/feed.xml"
+         * and "/u/feed.xml". We therefore need to find out how much to
+         * strip from the beginning of the string to give us a path that
+         * will be accepted by the file system.
+         */
+
+        if(channel.Url.StartsWith("/")){
+            offset = 0;
+        } else if(channel.Url.StartsWith("file:///")){
+            offset = 7;
+        } else if(channel.Url.StartsWith("file:/")){
+            offset = 5;
+        }
+
+        fs_path = channel.Url.Substring(offset, channel.Url.Length - offset);
+        try {
+            reader = File.OpenText(fs_path);
+        } catch(FileNotFoundException e){
+            System.Console.WriteLine("File {0} for URI {1} could not be found: {2}",
+                                      fs_path, channel.Url, e.Message);
+            return string.Empty;
+        }
+
+        return reader.ReadToEnd();
+    }
+
+	private static bool UpdateRssChannel (Channel channel, ref string feed_content)
 	{
 	    bool channelUpdated = false;
 
-	    RssReader reader = new RssReader (stream);
+	    RssReader reader = new RssReader(new StringReader(feed_content));
 	    RssChannel rssChannel = null;
 	    RssElement e;
 
@@ -295,33 +346,33 @@ namespace Imendio.Blam {
 	    return channelUpdated;
 	}
 
-	private static bool UpdateAtomChannel(Channel channel, Stream stream)
+	private static bool UpdateAtomChannel(Channel channel, ref string feed_content)
 	{
 	    bool channelUpdated = false;
 
 	    try {
-	        AtomFeed feed = AtomFeed.Load(stream);
+	        AtomFeed feed = AtomFeed.Load(new StringReader(feed_content));
 
 	        if (feed != null) {
 	            channel.StartRefresh();
 
 	            if ((channel.Name == "" || channel.Name == channel.Url) && 
-		        feed.Title.Content != null) {
-		        channel.Name = HtmlUtils.StripHtml(feed.Title.Content.Trim());
+		        feed.Title.Text != null) {
+		        channel.Name = HtmlUtils.StripHtml(feed.Title.Text.Trim());
 		        channelUpdated = true;
 	            }
 
-	            foreach (AtomEntry entry in feed.Entries) {
+	            foreach (AtomEntry entry in feed.Entry) {
 		        string id;
 		        bool   entryUpdated;
 
 		        id = GenerateItemId(entry);
-		        if (entry.Title.Content == "") {
-		            if (!entry.Modified.DateTime.Equals(DateTime.MinValue)) {
-		                entry.Title.Content = 
-		                    entry.Modified.DateTime.ToString("d MMM yyyy");
+		        if (entry.Title.Text == "") {
+		            if (!entry.Modified.Equals(DateTime.MinValue)) {
+		                entry.Title.Text = 
+		                    entry.Modified.ToString("d MMM yyyy");
 		            } else {
-		                entry.Title.Content = channel.Name;
+		                entry.Title.Text = channel.Name;
 		            }
 		        }
 
@@ -336,7 +387,7 @@ namespace Imendio.Blam {
 	    } catch (Exception) {
 	    }
 
-	  return channelUpdated;
+        return channelUpdated;
 	}
 
 	public static string GenerateItemId (RssItem item)
@@ -353,7 +404,7 @@ namespace Imendio.Blam {
 
 	public static string GenerateItemId (AtomEntry entry)
 	{
-	    return entry.Id.ToString();
+	    return entry.Id;
 	}
     }
 }
