@@ -8,6 +8,7 @@
 using GConf;
 using Gdk;
 using Gtk;
+using GLib;
 using GtkSharp;
 using System;
 using System.Collections;
@@ -23,6 +24,9 @@ namespace Imendio.Blam {
 	
 	private TreeViewColumn titleColumn; 
 
+    private Item lastItem;
+    private uint lastTimeout;
+
 	private Channel channel;
 	public Channel CurrentChannel {
 	    get {
@@ -197,11 +201,30 @@ namespace Imendio.Blam {
 
 	    item = (Imendio.Blam.Item) model.GetValue (iter, 0);
 	    if (item != null) {
-		EmitItemSelected (item);
-		item.SetUnread (false, true);
+            EmitItemSelected (item);
+
+            bool useTimeout = (bool) Conf.Get(Preference.MARK_ITEMS_READ, false);
+            if(useTimeout){
+                if(lastTimeout > 0)
+                    GLib.Source.Remove(lastTimeout);
+
+                uint readTimeout = (uint) Conf.Get(Preference.MARK_ITEMS_READ_TIMEOUT, 3000);
+                lastItem = item;
+                lastTimeout = GLib.Timeout.Add(readTimeout, new GLib.TimeoutHandler (SetToRead));
+            } else {
+                item.SetUnread(false, true);
+            }
 	    }
 	}
 
+    private bool SetToRead()
+    {
+        if(lastItem == GetSelected())
+                lastItem.SetUnread(false, true);
+
+        return false;
+    }
+
 	private SortFunc mItemSortFunc;
 	private int ItemSortFunc(IntPtr a, IntPtr b)
 	{
