@@ -8,7 +8,7 @@
 using Gdk;
 using Glade;
 using Gtk;
-using Mono.Posix;
+using Mono.Unix;
 using System;
 using System.Collections;
 using System.Globalization;
@@ -25,7 +25,7 @@ namespace Imendio.Blam {
 	[Widget] Gtk.Entry  urlEntry     = null;
 	[Widget] Gtk.Button importButton = null;
 
-	private Gtk.FileSelection fileDialog;
+	private Gtk.FileChooserDialog fileDialog;
 
 	private OpmlStatusDialog opmlStatusDialog;
 
@@ -52,7 +52,7 @@ namespace Imendio.Blam {
 
 	    mParentWindow = parentWindow;
 	    opmlDialog.TransientFor = mParentWindow;
-	    opmlDialog.Icon = Gdk.Pixbuf.LoadFromResource("blam.png");
+	    opmlDialog.IconName = "blam";
 
 	    dialogImage.Pixbuf =
 		Gdk.Pixbuf.LoadFromResource ("blam-add-news.png");
@@ -92,12 +92,13 @@ namespace Imendio.Blam {
 	public void FileButtonClicked(object obj, EventArgs args)
 	{
 	    if (fileDialog == null) {
-		fileDialog = new Gtk.FileSelection (Catalog.GetString ("Select OPML file"));
+		fileDialog = new Gtk.FileChooserDialog (Catalog.GetString ("Select OPML file"),
+                          this.opmlDialog, FileChooserAction.Open,
+                          Catalog.GetString("Cancel"), ResponseType.Cancel,
+                          Catalog.GetString("Open"), ResponseType.Ok);
 		fileDialog.Modal = true;
-		fileDialog.ShowFileops = false;
 	    }
 
-	    fileDialog.TransientFor = this.opmlDialog;
 	    int result = fileDialog.Run();
 	    
 	    switch (result) {
@@ -140,15 +141,10 @@ namespace Imendio.Blam {
 	public void ShowErrorDialog (string url, string errorMsg)
 	{
 	    string str = String.Format (Catalog.GetString ("Failed to import {0}"), url);
+	    Gtk.Dialog diag = ErrorDialog.Create(mParentWindow, str, errorMsg);
+	    diag.Run();
+	    diag.Destroy();
 
-	    Gtk.Dialog dialog = new HigDialog (mParentWindow,
-					       DialogFlags.Modal | DialogFlags.DestroyWithParent,
-					       MessageType.Error,
-					       ButtonsType.Ok,
-					       str,
-					       errorMsg);
-	    dialog.Run ();
-	    dialog.Destroy ();
 	}
 	
 	public static string GetXmlExceptionString ()
@@ -246,7 +242,7 @@ namespace Imendio.Blam {
 							    null);
 		gladeXML.Autoconnect(this);
 		opmlStatusDialog.TransientFor = parentWindow;
-		opmlStatusDialog.Icon = Gdk.Pixbuf.LoadFromResource("blam.png");
+		opmlStatusDialog.IconName = "blam";
 	    }
 
 	    public void Show (string initialStatus)
