@@ -22,6 +22,8 @@ namespace Imendio.Blam {
         public static string VARIABLE_FONT     = "/desktop/gnome/interface/font_name";
         public static string FIXED_FONT        = "/desktop/gnome/interface/monospace_font_name";
         public static string THEME             = "ui/theme";
+        public static string MARK_ITEMS_READ_TIMEOUT = "behaviour/set_item_read_timeout";
+        public static string MARK_ITEMS_READ    = "behaviour/set_item_read";
     }
 
     public class PreferencesDialog {
@@ -32,7 +34,9 @@ namespace Imendio.Blam {
         [Widget] Gtk.CheckButton ignoreSSLErr              = null;
         [Widget] Gtk.SpinButton  refreshRateSpinButton     = null;
         [Widget] Gtk.Label       boldThemeLabel            = null;
-        [Widget] Gtk.ComboBox	 themeComboBox             = null;
+        [Widget] Gtk.ComboBox    themeComboBox             = null;
+        [Widget] Gtk.CheckButton markItemsReadCheckButton  = null;
+        [Widget] Gtk.SpinButton  markItemsReadSpinButton   = null;
 
 		public PreferencesDialog (Gtk.Window parentWindow)
 		{
@@ -41,7 +45,7 @@ namespace Imendio.Blam {
 								null);
 			gladeXML.Autoconnect (this);
 			preferencesDialog.TransientFor = parentWindow;
-			preferencesDialog.Icon = Gdk.Pixbuf.LoadFromResource ("blam.png");
+			preferencesDialog.IconName = "blam";
 
 			boldBehaviourLabel.Markup = "<b>" + boldBehaviourLabel.Text + "</b>";
 			bool reverseEntries = Conf.Get (Preference.REVERSE_ENTRIES, false);
@@ -57,6 +61,12 @@ namespace Imendio.Blam {
 
 			themeComboBox.Changed += new EventHandler(ThemeSelectionChanged);
 
+            bool markItemsRead = Conf.Get(Preference.MARK_ITEMS_READ, false);
+            markItemsReadCheckButton.Active = markItemsRead;
+
+            int markItemsReadTimeout = Conf.Get(Preference.MARK_ITEMS_READ_TIMEOUT, 3000) / 1000;
+            markItemsReadSpinButton.Value = markItemsReadTimeout;
+
 			Conf.AddNotify (Preference.BEHAVIOUR_PATH, new NotifyEventHandler (ConfNotifyHandler));
 		}
 
@@ -88,7 +98,18 @@ namespace Imendio.Blam {
 			Conf.Set (Preference.AUTO_REFRESH_RATE,
 					  (int) refreshRateSpinButton.Value);
 		}
-		
+
+        public void MarkItemsReadCheckButtonToggled(object obj, EventArgs args)
+        {
+            Conf.Set(Preference.MARK_ITEMS_READ, markItemsReadCheckButton.Active);
+        }
+
+        public void MarkItemsReadSpinButtonChanged(object obj, EventArgs args)
+        {
+            int timeoutms = (int) markItemsReadSpinButton.Value * 1000;
+            Conf.Set(Preference.MARK_ITEMS_READ_TIMEOUT, timeoutms);
+        }
+
 		public void IgnoreSSLErrToggled (object obj, EventArgs args)
 		{
 		    Conf.Set (Preference.IGNORE_SSL_ERR,
